@@ -4,7 +4,7 @@ package Module::Build::SysPath;
 
 =head1 NAME
 
-Module::Build::SysPath - install files to system folders according to FHS (or Sys::Path settings)
+Module::Build::SysPath - Module::Build subclass with Sys::Path used in new() and ACTION_install()
 
 =head1 SYNOPSIS
 
@@ -15,141 +15,32 @@ Module::Build::SysPath - install files to system folders according to FHS (or Sy
 
 =head1 DESCRIPTION
 
-A subclass of L<Module::Build> using L<Sys::Path> to determine the system
-folders. Help in task of installing files into system folders and keeping
-the option to work in local distribution files while developing the module.
+A subclass of L<Module::Build>.
 
-See L<Acme::SysPath> for example usage of a module that needs a configuration
-and a folder to store templates in.
+See first L<Sys::Path>.
 
-=head1 USAGE
-
-=head2 module-starter
-
-    module-starter --builder=Module::Build --module=Acme::NewModule --author="Pod" --email=pod@pod
-    cd Acme-NewModule/
-    perl -lane 's/Module::Build-/Module::Build::SysPath-/; print $_;' -i Build.PL 
-    vim Build.PL
-    # s/Module::Build-/Module::Build::SysPath-/
-    # add "configure_requires => { 'Module::Build::SysPath' => 0.10 },"
-    # add "Module::Build::SysPath' => 0.10," to build_requires
-
-=head2 create SPc.pm
-
-copy L<http://github.com/jozef/Sys-Path/blob/master/examples/SPc.pm> and add
-it to your source tree. Clean up the paths that you don't need. Local distribution
-folder names can be changed to anyones taste. For example:
-
-    sub sysconfdir { File::Spec->catdir(__PACKAGE__->prefix, 'conf') };
-
-'conf' is the name of a folder with C<conffile>s. All file put to this folder
-will be installed to L<Sys::Path>->sysconfdir().
-
-=head2 use the SPc.pm
-
-Calling C<< Acme::NewModule::SPc->sysconfdir >> before the distribution is
-installed will return path to the 'conf' folder in the distribution root
-folder. Calling it after install the distribution will return L<Sys::Path>->sysconfdir().
-
-=head1 EXAMPLE
-
-See L<Acme::SysPath> for a really simple, L<Test::Daily> for a real world example.
+See L<Acme::SysPath> for example usage.
 
 =cut
 
 use warnings;
 use strict;
 
-our $VERSION = '0.14_01';
+our $VERSION = '0.09';
 
 use base 'Module::Build';
-use Sys::Path 0.11;
+use Sys::Path;
 use List::MoreUtils 'any';
 use FindBin '$Bin';
 use Digest::MD5 qw(md5_hex);
 use Text::Diff 'diff';
 use File::Spec;
-use File::Basename 'basename', 'dirname';
-use File::Path 'make_path';
 
 our $sys_path_config_name = 'SPc';
 
 =head2 new
 
-Populates:
-
-    $builder->{'properties'}->{$path_type.'_files'} = ...;
-    $builder->{'properties'}->{'install_path'}->{$path_type} = ...;
-    $builder->add_build_element($path_type);
-
-To install files located in:
-
-	sysconfdir
-	datadir
-	docdir
-	localedir
-	webdir
-
-Files in:
-
-    cachedir
-    logdir
-    spooldir
-    rundir
-    lockdir
-    sharedstatedir
-
-are skipped during the installation. Add F<.exists> to this folders if you
-want them to be created during `./Build install`.
-
-Configuration files get a special (Debian like) treatment. All files in
-C<sysconfdir> and all files specified as C<< $builder->{'properties'}->{'conffiles'} >>
-are configuration files. Using L<Sys::Path/install_checksums> the c<conffile>s
-checksums are tracked. Here are the model situations:
-
-=over 4
-
-=item C<conffile> was never installed jet
-
-The file is just copied in place (to sysconfdir) as it is. MD5 is recorded.
-
-=item distribution ships new version, no change in system
-
-The distribution changed the C<conffile> (for example by adding new values),
-but the C<conffile> was untouched in the system. Then the new version from
-distribution replaces the one in the system.
-
-=item distribution C<conffile> wasn't changed, C<conffile> changed in system
-
-Already installed distribution is getting upgrade. Distribution C<conffile>s form
-installed and the new version didn't change. But the C<conffile> was changed in
-the system. No prompt and the C<conffile> is kept intact.
-
-=item distribution C<conffile> change, C<conffile> changed in system
-
-Already installed distribution is getting upgrade. When both the distribution
-changed the C<conffile> and the C<conffile> was changed in the system. User will
-be prompted what to do:
-
-    Installing new version of config file /etc/SOMEFILE ...
-    
-    Configuration file `/etc/SOMEFILE'
-     ==> Modified (by you or by a script) since installation.
-     ==> Package distributor has shipped an updated version.
-       What would you like to do about it ?  Your options are:
-        Y or I  : install the package maintainer's version
-        N or O  : keep your currently-installed version
-          D     : show the differences between the versions
-          Z     : background this process to examine the situation
-     The default action is to keep your current version.
-    
-    *** /etc/SOMEFILE (Y/I/N/O/D/Z) ?
-
-If N or O is selected distribution files is installed with F<-spc>
-suffix. If Y or I is selected the system C<conffile> is renamed by adding
-suffix F<-old> and distribution C<conffile> is installed.
-
-=back
+TODO
 
 =cut
 
@@ -168,7 +59,6 @@ sub new {
     };
     
     my $distribution_root = Sys::Path->find_distribution_root($builder->module_name);
-    print 'dist root is ', $distribution_root, "\n";
     
     # map conf files to array of real paths
     my @conffiles = (
@@ -182,7 +72,6 @@ sub new {
     my %rename_in_system;
     my %conffiles_in_system;
     my @writefiles_in_system;
-    my @create_folders_in_system;
     foreach my $path_type ($module->_path_types) {
         my $sys_path     = $module->$path_type;
         my $install_path = Sys::Path->$path_type;
@@ -197,21 +86,12 @@ sub new {
             if any { $_ eq $path_type } ('prefix' ,'localstatedir');
 
         # prepare a list of files to install
-        my $non_persistant = (any { $_ eq $path_type} qw(cachedir logdir spooldir rundir lockdir sharedstatedir));
+        my $non_persistant = (any { $_ eq $path_type} qw(cachedir logdir spooldir rundir lockdir sharedstatedir webdir));
         if (-d $sys_path) {
             my %files;
-            my @ignore_folders;
             foreach my $file (@{$builder->rscan_dir($sys_path)}) {
-                # skip folders, but remember folders with . prefix
-                if (-d $file) {
-                    $file =~ s/$distribution_root.//;
-
-                    # ignore folders with . prefix
-                    push @ignore_folders, File::Spec->catfile($file, '')    # File::Spec with empty string to add portable trailing slash
-                        if (basename($file) =~ m{^\.} and (not exists $builder->{'properties'}->{$path_type.'_files'}->{$file}));
-
-                    next;
-                }
+                # skip folders
+                next if -d $file;
                 
                 my $blib_file = $file;
                 my $dest_file = $file;
@@ -220,28 +100,13 @@ sub new {
                 $blib_file    =~ s/^$sys_path.//;
                 $blib_file    = File::Spec->catfile($path_type, $blib_file);
                 
-                # allow empty directories to be created
-                push @create_folders_in_system, dirname($dest_file)
-                    if (basename($file) eq '.exists');
-                
                 # skip non-persistant folders, only include explicitely wanted and .exists files
                 next if
                     $non_persistant
+                    and ($file !~ m/\.exists$/)
                     and (not exists $builder->{'properties'}->{$path_type.'_files'}->{$file})
                 ;
                 
-                # skip files from .folders, only include explicitely wanted
-                next if any {
-                    ($file =~ m/^$_/)
-                    and (not exists $builder->{'properties'}->{$path_type.'_files'}->{$file})
-                } @ignore_folders;
-                
-                # skip files with . prefix
-                next if
-                    (basename($file) =~ m/^\./)
-                    and (basename($file) ne '.exists')
-                ;
-                
                 # print 'file>  ', $file, "\n";
                 # print 'bfile> ', $blib_file, "\n";
                 # print 'dfile> ', $dest_file, "\n\n";
@@ -278,14 +143,14 @@ sub new {
                 # add file the the Build.PL _files list
                 $files{$file} = $blib_file;
 
-                # make the conf and state files writable in the system
+                # make the conf and state files writeable in the system
                 push @writefiles_in_system, $dest_file
                     if any { $_ eq $path_type } qw(sharedstatedir sysconfdir);                
             }
             $builder->{'properties'}->{$path_type.'_files'} = \%files;
         }
                 
-        # set installation paths
+        # set instalation paths
         $builder->{'properties'}->{'install_path'}->{$path_type} = $install_path;
         
         # add build elements of the path types
@@ -295,16 +160,13 @@ sub new {
     $builder->notes('rename_in_system'     => \%rename_in_system);
     $builder->notes('conffiles_in_system'  => \%conffiles_in_system);
     $builder->notes('writefiles_in_system' => \@writefiles_in_system);
-    $builder->notes('create_folders_in_system' => \@create_folders_in_system);
     
     return $builder;
 }
 
 =head2 ACTION_install
 
-This action is responsible for renaming files, replacing F<SPc.pm> paths
-to systems once from L<Sys::Path>. Also makes files writable (chmod 0644).
-And stores the checksums of C<conffile>s.
+TODO
 
 =cut
 
@@ -320,15 +182,6 @@ sub ACTION_install {
             rename($system_file, $new_system_file) or die $!;
         }
     }
-    
-    # create requested folders
-    foreach my $folder (@{$builder->notes('create_folders_in_system')}) {
-        $folder = File::Spec->catdir($destdir || (), $folder);
-        if (not -d $folder) {
-            print 'Creating '.$folder.' folder', "\n";
-            make_path($folder);
-        }
-    }
 
     $builder->SUPER::ACTION_install(@_);
 
